Struct StrongAlg

pub struct StrongAlg<T>(pub T);
Wrapper around a JWT algorithm signalling that it supports only StrongKeys.

The wrapper will implement Algorithm if the wrapped value is an Algorithm with both signing and verifying keys convertible to StrongKeys.

Examples

let weak_key = Hs256Key::new(b"too short!");
assert!(StrongKey::try_from(weak_key).is_err());
// There is no way to create a `StrongKey` from `weak_key`!

let strong_key: StrongKey<_> = Hs256Key::generate(&mut thread_rng());
let claims = // ...
let token = StrongAlg(Hs256)
    .token(&Header::empty(), &claims, &strong_key)?;

Tuple Fields

0: T