pub struct WeakKeyError<T>(pub T);Expand description
Error type used for fallible conversion into a StrongKey.
The error wraps around a weak key, which can be extracted for further use.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> Debug for WeakKeyError<T>where
T: Debug,
impl<T> Debug for WeakKeyError<T>where
T: Debug,
Sourceimpl<T> Display for WeakKeyError<T>
impl<T> Display for WeakKeyError<T>
Sourceimpl<T> Error for WeakKeyError<T>where
T: Debug + 'static,
impl<T> Error for WeakKeyError<T>where
T: Debug + 'static,
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()