#[non_exhaustive]pub enum ValidationError {
AlgorithmMismatch {
expected: String,
actual: String,
},
InvalidSignatureLen {
expected: usize,
actual: usize,
},
MalformedSignature(Error),
InvalidSignature,
MalformedClaims(Error),
NoClaim(Claim),
Expired,
NotMature,
}Expand description
Errors that can occur during token validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlgorithmMismatch
Algorithm mentioned in the token header differs from invoked one.
InvalidSignatureLen
Token signature has invalid byte length.
MalformedSignature(Error)
Token signature is malformed.
InvalidSignature
Token signature has failed verification.
MalformedClaims(Error)
Token claims cannot be deserialized from JSON.
NoClaim(Claim)
Claim requested during validation is not present in the token.
Expired
Token has expired.
NotMature
Token is not yet valid as per nbf claim.