Struct Claims

pub struct Claims<T> {
    pub expiration: Option<DateTime<Utc>>,
    pub not_before: Option<DateTime<Utc>>,
    pub issued_at: Option<DateTime<Utc>>,
    pub custom: T,
}
Claims encoded in a token.

Claims are comprised of a “standard” part (exp, nbf and iat claims as per JWT spec), and custom fields. iss, sub and aud claims are not in the standard part due to a variety of data types they can be reasonably represented by.

Fields

expiration: Option<DateTime<Utc>>

Expiration time of the token.

not_before: Option<DateTime<Utc>>

Minimum time at which token is valid.

issued_at: Option<DateTime<Utc>>

Time of token issuance.

custom: T

Custom claims.

Implementations

Source

impl Claims<Empty>

pub const fn empty() -> Claims<Empty>

Creates an empty claims instance.

Source

impl<T> Claims<T>

pub const fn new(custom_claims: T) -> Claims<T>

Creates a new instance with the provided custom claims.

pub fn set_duration<F>( self, options: &TimeOptions<F>, duration: TimeDelta, ) -> Claims<T>
where F: Fn() -> DateTime<Utc>,

Sets the expiration claim so that the token has the specified duration. The current timestamp is taken from options.

pub fn set_duration_and_issuance<F>( self, options: &TimeOptions<F>, duration: TimeDelta, ) -> Claims<T>
where F: Fn() -> DateTime<Utc>,

Atomically sets issued_at and expiration claims: first to the current time (taken from options), and the second to match the specified duration of the token.

pub fn set_not_before(self, moment: DateTime<Utc>) -> Claims<T>

Sets the nbf claim.

pub fn validate_expiration<F>( &self, options: &TimeOptions<F>, ) -> Result<&Claims<T>, ValidationError>
where F: Fn() -> DateTime<Utc>,

Validates the expiration claim.

This method will return an error if the claims do not feature an expiration time, or if it is in the past (subject to the provided options).

pub fn validate_maturity<F>( &self, options: &TimeOptions<F>, ) -> Result<&Claims<T>, ValidationError>
where F: Fn() -> DateTime<Utc>,

Validates the maturity time (nbf claim).

This method will return an error if the claims do not feature a maturity time, or if it is in the future (subject to the provided options).