Struct Renamed

pub struct Renamed<A> { /* private fields */ }
Algorithm that uses a custom name when creating and validating tokens.

Examples

use jwt_compact_frame::{alg::{Hs256, Hs256Key}, prelude::*, Empty, Renamed};

let alg = Renamed::new(Hs256, "HS2");
let key = Hs256Key::new(b"super_secret_key_donut_steel");
let token_string = alg.token(&Header::empty(), &Claims::empty(), &key)?;

let token = UntrustedToken::new(&token_string)?;
assert_eq!(token.algorithm(), "HS2");
// Note that the created token cannot be verified against the original algorithm
// since the algorithm name recorded in the token header doesn't match.
assert!(Hs256.validator::<Empty>(&key).validate(&token).is_err());

// ...but the modified alg is working as expected.
assert!(alg.validator::<Empty>(&key).validate(&token).is_ok());

Implementations

Source

impl<A> Renamed<A>
where A: Algorithm,

pub const fn new(algorithm: A, new_name: &'static str) -> Renamed<A>

Creates a renamed algorithm.