pub struct SampleClaims<AccountId> {
pub subject: AccountId,
pub issuer: String,
pub ipfs_cid: Cid,
pub investor_type: InvestorType,
pub did: Did,
}Fields
subject: AccountIdissuer: Stringipfs_cid: Cidinvestor_type: InvestorTypedid: DidTrait Implementations
Sourceimpl<AccountId: Clone> Clone for SampleClaims<AccountId>
impl<AccountId: Clone> Clone for SampleClaims<AccountId>
Sourcefn clone(&self) -> SampleClaims<AccountId>
fn clone(&self) -> SampleClaims<AccountId>
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<AccountId> Debug for SampleClaims<AccountId>where
AccountId: Debug,
impl<AccountId> Debug for SampleClaims<AccountId>where
AccountId: Debug,
Sourceimpl<AccountId> Decode for SampleClaims<AccountId>where
AccountId: Decode,
impl<AccountId> Decode for SampleClaims<AccountId>where
AccountId: Decode,
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de, AccountId> Deserialize<'de> for SampleClaims<AccountId>where
AccountId: Deserialize<'de>,
impl<'de, AccountId> Deserialize<'de> for SampleClaims<AccountId>where
AccountId: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<AccountId> Encode for SampleClaims<AccountId>where
AccountId: Encode,
impl<AccountId> Encode for SampleClaims<AccountId>where
AccountId: Encode,
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl<AccountId: Ord> Ord for SampleClaims<AccountId>
impl<AccountId: Ord> Ord for SampleClaims<AccountId>
Sourcefn cmp(&self, other: &SampleClaims<AccountId>) -> Ordering
fn cmp(&self, other: &SampleClaims<AccountId>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<AccountId: PartialEq> PartialEq for SampleClaims<AccountId>
impl<AccountId: PartialEq> PartialEq for SampleClaims<AccountId>
Sourceimpl<AccountId: PartialOrd> PartialOrd for SampleClaims<AccountId>
impl<AccountId: PartialOrd> PartialOrd for SampleClaims<AccountId>
Sourceimpl<AccountId> Serialize for SampleClaims<AccountId>where
AccountId: Serialize,
impl<AccountId> Serialize for SampleClaims<AccountId>where
AccountId: Serialize,
Sourceimpl<AccountId> TypeInfo for SampleClaims<AccountId>where
AccountId: TypeInfo + 'static,
impl<AccountId> TypeInfo for SampleClaims<AccountId>where
AccountId: TypeInfo + 'static,
impl<AccountId> EncodeLike for SampleClaims<AccountId>where
AccountId: Encode,
impl<AccountId: Eq> Eq for SampleClaims<AccountId>
impl<AccountId> StructuralPartialEq for SampleClaims<AccountId>