pub enum SendError {
NotApplicable,
Transport(&'static str),
Unroutable,
DestinationUnsupported,
ExceedsMaxMessageSize,
MissingArgument,
Fees,
}Expand description
Error result value when attempting to send an XCM message.
Variants
NotApplicable
The message and destination combination was not recognized as being reachable.
This is not considered fatal: if there are alternative transport routes available, then they may be attempted.
Transport(&'static str)
Destination is routable, but there is some issue with the transport mechanism. This is considered fatal. A human-readable explanation of the specific issue is provided.
Unroutable
Destination is known to be unroutable. This is considered fatal.
DestinationUnsupported
The given message cannot be translated into a format that the destination can be expected to interpret.
ExceedsMaxMessageSize
Message could not be sent due to its size exceeding the maximum allowed by the transport layer.
MissingArgument
A needed argument is None when it should be Some.
Fees
Fees needed to be paid in order to send the message and they were unavailable.