pub struct MigrationInfo {
pub contribution_token_amount: u128,
pub vesting_time: u64,
}Fields
contribution_token_amount: u128vesting_time: u64Trait Implementations
Sourceimpl Clone for MigrationInfo
impl Clone for MigrationInfo
Sourcefn clone(&self) -> MigrationInfo
fn clone(&self) -> MigrationInfo
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigrationInfo
impl Debug for MigrationInfo
Sourceimpl Decode for MigrationInfo
impl Decode for MigrationInfo
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for MigrationInfo
impl Encode for MigrationInfo
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl MaxEncodedLen for MigrationInfo
impl MaxEncodedLen for MigrationInfo
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl PartialEq for MigrationInfo
impl PartialEq for MigrationInfo
Sourceimpl TypeInfo for MigrationInfo
impl TypeInfo for MigrationInfo
impl EncodeLike for MigrationInfo
impl Eq for MigrationInfo
impl StructuralPartialEq for MigrationInfo