pub struct MigrationOrigin {
pub user: Location,
pub id: u32,
pub participation_type: ParticipationType,
}Fields
user: Locationid: u32participation_type: ParticipationTypeTrait Implementations
Sourceimpl Clone for MigrationOrigin
impl Clone for MigrationOrigin
Sourcefn clone(&self) -> MigrationOrigin
fn clone(&self) -> MigrationOrigin
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigrationOrigin
impl Debug for MigrationOrigin
Sourceimpl Decode for MigrationOrigin
impl Decode for MigrationOrigin
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for MigrationOrigin
impl Encode for MigrationOrigin
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl MaxEncodedLen for MigrationOrigin
impl MaxEncodedLen for MigrationOrigin
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl Ord for MigrationOrigin
impl Ord for MigrationOrigin
Sourceimpl PartialEq for MigrationOrigin
impl PartialEq for MigrationOrigin
Sourceimpl PartialOrd for MigrationOrigin
impl PartialOrd for MigrationOrigin
Sourceimpl TypeInfo for MigrationOrigin
impl TypeInfo for MigrationOrigin
impl EncodeLike for MigrationOrigin
impl Eq for MigrationOrigin
impl StructuralPartialEq for MigrationOrigin