pub struct Assets(/* private fields */);Expand description
A Vec of Assets.
There are a number of invariants which the construction and mutation functions must ensure are maintained:
- It may contain no items of duplicate asset class;
- All items must be ordered;
- The number of items should grow no larger than
MAX_ITEMS_IN_ASSETS.
Implementations
Sourceimpl Assets
impl Assets
Sourcepub fn from_sorted_and_deduplicated(r: Vec<Asset>) -> Result<Assets, ()>
pub fn from_sorted_and_deduplicated(r: Vec<Asset>) -> Result<Assets, ()>
Create a new instance of Assets from a Vec<Asset> whose contents are sorted
and which contain no duplicates.
Returns Ok if the operation succeeds and Err if r is out of order or had duplicates.
If you can’t guarantee that r is sorted and deduplicated, then use
From::<Vec<Asset>>::from which is infallible.
Sourcepub fn from_sorted_and_deduplicated_skip_checks(r: Vec<Asset>) -> Assets
pub fn from_sorted_and_deduplicated_skip_checks(r: Vec<Asset>) -> Assets
Create a new instance of Assets from a Vec<Asset> whose contents are sorted
and which contain no duplicates.
In release mode, this skips any checks to ensure that r is correct, making it a
negligible-cost operation. Generally though you should avoid using it unless you have a
strict proof that r is valid.
In test mode, this checks anyway and panics on fail.
Sourcepub fn push(&mut self, a: Asset)
pub fn push(&mut self, a: Asset)
Add some asset onto the list, saturating. This is quite a laborious operation since it maintains the ordering.
Sourcepub fn contains(&self, inner: &Asset) -> bool
pub fn contains(&self, inner: &Asset) -> bool
Returns true if self is a super-set of the given inner asset.
Sourcepub fn drain(self) -> Vec<Asset>
👎Deprecated: Use into_inner() instead
pub fn drain(self) -> Vec<Asset>
into_inner() insteadConsume self and return the inner vec.
Sourcepub fn into_inner(self) -> Vec<Asset>
pub fn into_inner(self) -> Vec<Asset>
Consume self and return the inner vec.