pub struct StrongAlg<T>(pub T);Expand description
Wrapper around a JWT algorithm signalling that it supports only StrongKeys.
The wrapper will implement Algorithm if the wrapped value is an Algorithm with both
signing and verifying keys convertible to StrongKeys.
Examples
let weak_key = Hs256Key::new(b"too short!");
assert!(StrongKey::try_from(weak_key).is_err());
// There is no way to create a `StrongKey` from `weak_key`!
let strong_key: StrongKey<_> = Hs256Key::generate(&mut thread_rng());
let claims = // ...
let token = StrongAlg(Hs256)
.token(&Header::empty(), &claims, &strong_key)?;Tuple Fields
0: TTrait Implementations
Sourceimpl<T> Algorithm for StrongAlg<T>where
T: Algorithm,
StrongKey<<T as Algorithm>::SigningKey>: TryFrom<<T as Algorithm>::SigningKey>,
StrongKey<<T as Algorithm>::VerifyingKey>: TryFrom<<T as Algorithm>::VerifyingKey>,
impl<T> Algorithm for StrongAlg<T>where
T: Algorithm,
StrongKey<<T as Algorithm>::SigningKey>: TryFrom<<T as Algorithm>::SigningKey>,
StrongKey<<T as Algorithm>::VerifyingKey>: TryFrom<<T as Algorithm>::VerifyingKey>,
Sourcetype SigningKey = StrongKey<<T as Algorithm>::SigningKey>
type SigningKey = StrongKey<<T as Algorithm>::SigningKey>
Key used when issuing new tokens.
Sourcetype VerifyingKey = StrongKey<<T as Algorithm>::VerifyingKey>
type VerifyingKey = StrongKey<<T as Algorithm>::VerifyingKey>
Key used when verifying tokens. May coincide with
Self::SigningKey for symmetric
algorithms (e.g., HS*).Sourcefn name(&self) -> Cow<'static, str>
fn name(&self) -> Cow<'static, str>
Returns the name of this algorithm, as mentioned in the
alg field of the JWT header.impl<T> Copy for StrongAlg<T>where
T: Copy,