pub struct Claims<T> {
pub expiration: Option<DateTime<Utc>>,
pub not_before: Option<DateTime<Utc>>,
pub issued_at: Option<DateTime<Utc>>,
pub custom: T,
}Expand description
Claims encoded in a token.
Claims are comprised of a “standard” part (exp, nbf and iat claims as per JWT spec),
and custom fields. iss, sub and aud claims are not in the standard part
due to a variety of data types they can be reasonably represented by.
Fields
expiration: Option<DateTime<Utc>>Expiration time of the token.
not_before: Option<DateTime<Utc>>Minimum time at which token is valid.
issued_at: Option<DateTime<Utc>>Time of token issuance.
custom: TCustom claims.
Implementations
Sourceimpl<T> Claims<T>
impl<T> Claims<T>
Sourcepub const fn new(custom_claims: T) -> Claims<T>
pub const fn new(custom_claims: T) -> Claims<T>
Creates a new instance with the provided custom claims.
Sourcepub fn set_duration<F>(
self,
options: &TimeOptions<F>,
duration: TimeDelta,
) -> Claims<T>
pub fn set_duration<F>( self, options: &TimeOptions<F>, duration: TimeDelta, ) -> Claims<T>
Sets the expiration claim so that the token has the specified duration.
The current timestamp is taken from options.
Sourcepub fn set_duration_and_issuance<F>(
self,
options: &TimeOptions<F>,
duration: TimeDelta,
) -> Claims<T>
pub fn set_duration_and_issuance<F>( self, options: &TimeOptions<F>, duration: TimeDelta, ) -> Claims<T>
Atomically sets issued_at and expiration claims: first to the current time
(taken from options), and the second to match the specified duration of the token.
Sourcepub fn set_not_before(self, moment: DateTime<Utc>) -> Claims<T>
pub fn set_not_before(self, moment: DateTime<Utc>) -> Claims<T>
Sets the nbf claim.
Sourcepub fn validate_expiration<F>(
&self,
options: &TimeOptions<F>,
) -> Result<&Claims<T>, ValidationError>
pub fn validate_expiration<F>( &self, options: &TimeOptions<F>, ) -> Result<&Claims<T>, ValidationError>
Validates the expiration claim.
This method will return an error if the claims do not feature an expiration time,
or if it is in the past (subject to the provided options).
Sourcepub fn validate_maturity<F>(
&self,
options: &TimeOptions<F>,
) -> Result<&Claims<T>, ValidationError>
pub fn validate_maturity<F>( &self, options: &TimeOptions<F>, ) -> Result<&Claims<T>, ValidationError>
Validates the maturity time (nbf claim).
This method will return an error if the claims do not feature a maturity time,
or if it is in the future (subject to the provided options).