pub struct UntrustedToken<H = Empty> { /* private fields */ }Expand description
Parsed, but unvalidated token.
The type param (Empty by default) corresponds to the additional information enclosed
in the token Header.
An UntrustedToken can be parsed from a string using the TryFrom implementation.
This checks that a token is well-formed (has a header, claims and a signature),
but does not validate the signature.
As a shortcut, a token without additional header info can be created using Self::new().
Examples
let token_str = "eyJ0eXAiOiJKV1QiLA0KICJhbGciOiJIUzI1NiJ9.eyJp\
c3MiOiJqb2UiLA0KICJleHAiOjEzMDA4MTkzODAsDQogImh0dHA6Ly9leG\
FtcGxlLmNvbS9pc19yb290Ijp0cnVlfQ.dBjftJeZ4CVP-mB92K27uhbUJ\
U1p1r_wW1gFWFOEjXk";
let token: UntrustedToken = token_str.try_into()?;
// The same operation using a shortcut:
let same_token = UntrustedToken::new(token_str)?;
// Token header can be accessed to select the verifying key etc.
let key_id: Option<&str> = token.header().key_id.as_deref();Handling tokens with custom header fields
#[derive(Debug, Clone, Deserialize)]
struct HeaderExtensions {
custom: String,
}
let token_str = "eyJhbGciOiJIUzI1NiIsImtpZCI6InRlc3Rfa2V5Iiwid\
HlwIjoiSldUIiwiY3VzdG9tIjoiY3VzdG9tIn0.eyJzdWIiOiIxMjM0NTY\
3ODkwIiwibmFtZSI6IkpvaG4gRG9lIiwiYWRtaW4iOnRydWV9._27Fb6nF\
Tg-HSt3vO4ylaLGcU_ZV2VhMJR4HL7KaQik";
let token: UntrustedToken<HeaderExtensions> = token_str.try_into()?;
let extensions = &token.header().other_fields;
println!("{}", extensions.custom);Implementations
Sourceimpl<'a> UntrustedToken
impl<'a> UntrustedToken
Sourcepub fn new<S>(s: &'a S) -> Result<UntrustedToken, ParseError>
pub fn new<S>(s: &'a S) -> Result<UntrustedToken, ParseError>
Creates an untrusted token from a string. This is a shortcut for calling the TryFrom
conversion.
Sourceimpl<H> UntrustedToken<H>
impl<H> UntrustedToken<H>
Sourcepub fn into_owned(self) -> UntrustedToken<H>
pub fn into_owned(self) -> UntrustedToken<H>
Converts this token to an owned form.
Sourcepub fn signature_bytes(&self) -> &[u8] ⓘ
pub fn signature_bytes(&self) -> &[u8] ⓘ
Returns signature bytes from the token. These bytes are not guaranteed to form a valid signature.
Sourcepub fn deserialize_claims_unchecked<T>(
&self,
) -> Result<Claims<T>, ValidationError>where
T: DeserializeOwned,
pub fn deserialize_claims_unchecked<T>(
&self,
) -> Result<Claims<T>, ValidationError>where
T: DeserializeOwned,
Deserializes claims from this token without checking token integrity. The resulting claims are thus not guaranteed to be valid.